@@ -10,12 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import json
-
 from django.urls import reverse
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from oslo_log import log as logging
+from oslo_serialization import jsonutils
 
 from horizon import exceptions
 from horizon import forms
@@ -93,13 +92,16 @@ class DetailView(tabs.TabView):
 
         try:
             vnffg = tacker_api.tacker.get_vnffg(self.request, vnffg_id)
-            vnffg["vnffg"]["mgmt_url"] = json.loads(
-                vnffg["vnffg"]["mgmt_url"]) if vnffg["vnffg"].get(
-                "mgmt_url") else None
+            vnffg["vnffg"]["mgmt_ip_address"] = jsonutils.loads(
+                vnffg["vnffg"]["mgmt_ip_address"]) if vnffg["vnffg"].get(
+                "mgmt_ip_address") else None
             return vnffg
         except ValueError as e:
             msg = _('Cannot decode json : %s') % e
             LOG.error(msg)
+        except KeyError as err:
+            msg = _('Required field %s not specified') % err.args[0]
+            LOG.error(msg)
         except Exception:
             redirect = reverse(self.redirect_url)
             exceptions.handle(self.request,
